@@ -17,6 +17,11 @@
 
 using namespace Dasher;
 
+enum accessibletype { menus=1, toolbars=2, pushbuttons=3, focusables=4, textenter=5 };
+
+void setupa11y();
+void cleanupa11y();
+
 ControlTree* gettree();
 ControlTree* buildcontroltree();
 ControlTree* buildmovetree(ControlTree* movetree);
@@ -24,7 +29,10 @@ ControlTree* builddeletetree(ControlTree* movetree);
 ControlTree* buildspeaktree(ControlTree* speaktree);
 void deletemenutree();
 #ifdef GNOME_A11Y
-bool buildmenutree(Accessible *parent, ControlTree *ctree);
+bool buildmenutree(Accessible *parent, ControlTree *ctree, accessibletype Type);
 ControlTree* getmenutree();
+gboolean dasher_check_window(AccessibleRole role);
+gboolean findpanels(Accessible *parent);
 #endif
 #endif
+
